package Bundle::FinalTest;

use 5.010001;
use strict;
use warnings;
require Exporter;
our $VERSION = '0.01';


# Preloaded methods go here.

1;
__END__
# Below is stub documentation for your module. You'd better edit it!

=head1 NAME

Bundle::FinalTest - Perl extension for blah blah blah

=head1 SYNOPSIS

  use Bundle::FinalTest;
  blah blah blah

=head1 DESCRIPTION

Stub documentation for Bundle::FinalTest, created by h2xs. It looks like the
author of the extension was negligent enough to leave the stub
unedited.

Blah blah blah.
=head1 CONTENTS

AnyDBM_File
Attribute::Handlers
BerkeleyDB
Carp
Class::Data::Inheritable
Class::Singleton
Compress::Raw::Bzip2
Compress::Raw::Zlib
Crypt::OpenSSL::Random
Crypt::RC4
Data::Dump
Date::Format
Date::Parse
DB_File
Digest::SHA
DirHandle
Encode
Exporter
FCGI
File::Find
File::Glob
File::Grep
File::Stat::Bits
Filter::Util::Call
GD
GD::Text
Geography::Countries
Geo::IP
Getopt::Std
HTML::HTMLDoc
HTML::Tagset
Image::Magick
integer
IO::Dir
IO::File
IO::Scalar
IO::Socket::INET
IO::Stringy
Locale::Maketext::Simple
LWP::MediaTypes
Math::Round
MD5
MIME::Base64
MIME::QuotedPrint
MLDBM::Sync
mod_perl2
Net::CIDR::Lite
Net::Domain
Net::FTP
Net::IP
Net::Ping
Number::Compare
OLE::Storage_Lite
overload
Pod::Escapes
Probe::Perl
Scalar::Util::Numeric
Storable
String::CRC32
Sys::Hostname
Sys::Hostname::Long
Term::ReadKey
Term::ReadLine
Test
Test::Harness
Test::Inter
Text::Wrap
Tie::Cache
Time::Local
Time::Piece
vars
Warnings


Digest::Perl::MD5
Encode::Locale
ExtUtils::Install
File::Path
File::Slurp
HTTP::Date
IP::Country
Test::Builder
Test::More
Test::Simple
Text::Abbrev
Crypt::OpenSSL::RSA
Digest::base


Algorithm::C3
AppConfig
base
Devel::Symdump
Email::Date::Format
File::Listing
File::Type
GD::Graph
GD::SecurityImage
IO::Pty
JSON
JSON::PP
List::MoreUtils
List::Util
MIME::Types
MLDBM
Module::CoreList
Module::Load
NetAddr::IP
Package::Constants
Params::Check
parent
Pod::Find
Pod::Simple
Pod::Usage
Scalar::Util
String::Approx
Sub::Uplevel
Test::Tester
Text::Balanced
Text::Glob
Time::HiRes
Try::Tiny
URI
URI::Escape
XSLoader
Digest::SHA1
Compress::Bzip2


Class::Accessor
Compress::Zlib
Cwd
Error
File::Find::Rule
File::Spec
File::Spec::Functions
Getopt::Long
HTML::Parser
IO::Compress::Base
IO::Compress::Bzip2
IO::Compress::Gzip
IO::Uncompress::Inflate
IPC::Run
IPC::Run3
MIME::Lite
Pod::Coverage
Test::Exception
Test::Fatal
Test::NoWarnings
Test::Pod
WWW::RobotRules
Digest::MD5
Email::Simple


CGI
Config::General
CPAN::Meta::YAML
Data::Compare
Devel::StackTrace
File::Temp
IO::Zlib
Mail::Internet
Module::Info
Module::Pluggable
Net::HTTP
Pod::Man
Test::Pod::Coverage
Test::Deep
Carp::Clan
Digest::StackTrace
Digest::HMAC
Digest::HMAC_MD5
HTML::Template
HTTP::Headers::Util
HTTP::Status


Archive::Tar
Archive::Zip
HTTP::Tiny
Perl::OSType
Template
Version
Apache::Session
CGI::Session
Bit::Vector
Exception::Class
ExtUtils::MakeMaker
HTTP::Cookies
HTTP::Daemon
HTTP::Headers
Test::Pod::Coverage


Module::Load::Conditional
Module::Metadata
Net::DNS
Parse::RecDescent
Version::Requirements
Class::C3
Class::Load
Date::Calc
DBI
HTTP::Negotiate
MIME::Tools
Parse::CPAN::Meta
Test::Script
XML::NamespaceSupport
YAML
YAML::Syck
YAML::XS


CPAN::Meta
Date::Manip
DBD::Pg
File::Which
IPC::Cmd
LWP
LWP::UserAgent
Module::Signature
MRO::Compat
Spreadsheet::WriteExcel
XML::SAX


CPAN::Checksums
Email::Abstract
ExtUtils::CBuilder
File::HomeDir
XML
Spreadsheet::WriteExcel::Simple


Email::Date
ExtUtils::ParseXS
Spreadsheet::ParseExcel


Module::Build


CPAN
HTML::Tree
Image::Size
Params::Validate


DateTime::Locale
DateTime::Zone

DataTime
=head2 EXPORT

None by default.



=head1 SEE ALSO

Mention other useful documentation such as the documentation of
related modules or operating system documentation (such as man pages
in UNIX), or any relevant external documentation such as RFCs or
standards.

If you have a mailing list set up for your module, mention it here.

If you have a web site set up for your module, mention it here.

=head1 AUTHOR

ansh batra, E<lt>root@(none)E<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 by root

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.10.1 or,
at your option, any later version of Perl 5 you may have available.


=cut
